package PureMessage::Policy::DKIM;

use strict;
use warnings;

use base 'PureMessage::Policy::Plugin';
use PureMessage::Policy::Plugin::Utils qw(get_matcher);

our @EXPORT_OK = qw(pmx_dkim_verify pmx_dkim_sign);
our $VERSION   = '5.507';

my %commands = (
    pmx_dkim_verify => \&pmx_dkim_verify,
    pmx_dkim_sign => \&pmx_dkim_sign,
);

sub new {
    my $class = shift;
    my %opts = @_;
    return bless \%opts, $class;
}

sub commands {
    my $self = shift;
    return %commands;
}

sub pmx_dkim_verify {
    my ($msg, $args) = @_;

    my $matcher = get_matcher($msg, $args);
    my $result = $msg->get_attr("mark_DKIM-VERIFY");
    return $matcher->($result) if $result;
    
    $result = $msg->dkim_verify();
    $msg->set_attr("mark_DKIM-VERIFY", $result);
    return $matcher->($result);
}

sub pmx_dkim_sign {
    my ($msg, $args) = @_;
    $msg->set_attr('dkim_sign', 1);
}

1;

