package PureMessage::Policy::DKIM::Config;

use strict;
use warnings;
use PureMessage::Config qw(expand_filename);
use base qw(PureMessage::Config::Validator Exporter);

our @EXPORT_OK = '%dkim_config';
our %dkim_config;

# Validation rules and default values.
my %conf = (
    'algorithm' => ['#str', 'rsa-sha256'],
    'method'    => ['#str', 'relaxed/relaxed'],
    'domain'    => ['#str', undef],
    'selector'  => ['#str', undef],
    'keyfile'   => ['#str', undef],
);

refresh();

sub new {
    my $self = shift;
    my $p = ActiveState::Config->new(strict => 1, allow_includes => 1);
    PureMessage::Policy::DKIM::Config->validate($p);
    $p->parse_file(expand_filename("etc/dkim.conf"));
    $p->as_hash;
    $p;
}

sub refresh {
    %dkim_config = new(undef)->as_hash;
}

sub validate {
    my ($pkg, $p) = @_;

    # Add our validation rules to the parser.
    foreach my $key (keys %conf) {
        my ($type, $def) = @{$conf{$key}};
        $p->typedecl( $key, $type ) if (defined $type);
        $p->default(  $key, $def )  if (defined $def);
    }
}

1;

